@@ -2,7 +2,6 @@ import asyncio
 import logging
 import traceback
 from asyncio import AbstractEventLoop as Loop
-from collections import defaultdict
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
 from typing import Optional
@@ -13,19 +12,18 @@ from discord.ext.commands import Bot, errors
 from discord_slash import SlashCommand, context
 from expiringdict import ExpiringDict
 
-from spellbot.database import (
-    db_session_manager,
-    get_legacy_prefixes,
-    initialize_connection,
+from .database import db_session_manager, initialize_connection
+from .errors import (
+    AdminOnlyError,
+    UserBannedError,
+    UserUnverifiedError,
+    UserVerifiedError,
 )
-from spellbot.errors import SpellbotAdminOnly, UserBannedError
-from spellbot.operations import safe_message_reply, safe_send_channel
-from spellbot.services.channels import ChannelsService
-from spellbot.services.guilds import GuildsService
-from spellbot.services.verifies import VerifiesService
-from spellbot.settings import Settings
-from spellbot.spelltable import generate_link
-from spellbot.utils import user_can_moderate
+from .operations import safe_send_channel
+from .services import ChannelsService, GuildsService, VerifiesService
+from .settings import Settings
+from .spelltable import generate_link
+from .utils import user_can_moderate
 
 logger = logging.getLogger(__name__)
 
@@ -49,7 +47,6 @@ class SpellBot(Bot):
             intents=intents,
         )
         self.mock_games = mock_games
-        self.legacy_prefix_cache = defaultdict(lambda: "!")
         self.channel_locks = ExpiringDict(max_len=100, max_age_seconds=3600)  # 1 hr
 
     @asynccontextmanager
@@ -71,7 +68,7 @@ class SpellBot(Bot):
                 "This command is not supported via Direct Message.",
                 hidden=True,
             )
-        if isinstance(ex, SpellbotAdminOnly):
+        if isinstance(ex, AdminOnlyError):
             return await safe_send_channel(
                 ctx,
                 "You do not have permission to do that.",
@@ -83,6 +80,18 @@ class SpellBot(Bot):
                 "You have been banned from using SpellBot.",
                 hidden=True,
             )
+        if isinstance(ex, UserVerifiedError):
+            return await safe_send_channel(
+                ctx,
+                "Only unverified users can do that in this channel.",
+                hidden=True,
+            )
+        if isinstance(ex, UserUnverifiedError):
+            return await safe_send_channel(
+                ctx,
+                "Only verified users can do that in this channel.",
+                hidden=True,
+            )
 
         ref = (
             f"command `{ctx.name}`"
@@ -123,21 +132,6 @@ class SpellBot(Bot):
         async with db_session_manager():
             await self.handle_verification(message)
 
-        guild_xid = message.guild.id  # type: ignore
-        if message.content.startswith(self.legacy_prefix_cache[guild_xid]):
-            settings = Settings()
-            embed = discord.Embed()
-            embed.set_thumbnail(url=settings.ICO_URL)
-            embed.description = (
-                "SpellBot uses [slash commands]"
-                "(https://discord.com/blog/slash-commands-are-here) now."
-                " Type `/` to see the list of commands! If you don't see any, please"
-                " [re-invite the bot using its new invite link]"
-                f"({settings.BOT_INVITE_LINK})."
-            )
-            embed.color = settings.EMBED_COLOR
-            await safe_message_reply(message, embed=embed, delete_after=10.0)
-
     async def handle_verification(self, message: discord.Message):
         # To verify users we need their user id, so just give up if it's not available
         if not hasattr(message.author, "id"):
@@ -186,19 +180,14 @@ def build_bot(
     # Note: In tests we create the connection using fixtures.
     if create_connection:  # pragma: no cover
 
-        async def bot_connection(bot):
+        async def bot_connection():
             logger.info("initializing database connection...")
             await initialize_connection("spellbot-bot")
 
-            async with db_session_manager():
-                logger.info("building legacy command prefix cache...")
-                db_legacy_prefixes = await get_legacy_prefixes()
-                bot.legacy_prefix_cache.update(db_legacy_prefixes)
-
-        bot.loop.run_until_complete(bot_connection(bot))
+        bot.loop.run_until_complete(bot_connection())
 
     # load all cog extensions
-    from spellbot.cogs import load_all_cogs
+    from .cogs import load_all_cogs
 
     load_all_cogs(bot)
     commands = (key for key in bot.slash.commands if key != "context")
