@@ -1,3 +1,5 @@
+# pylint: disable=wrong-import-order
+
 import logging
 from contextlib import asynccontextmanager
 from contextvars import ContextVar
@@ -11,8 +13,7 @@ from sqlalchemy.orm import sessionmaker
 from sqlalchemy.orm.session import Session
 from wrapt import CallableObjectProxy
 
-from spellbot.models import create_all
-from spellbot.models.guild import Guild
+from .models import create_all
 
 logger = logging.getLogger(__name__)
 ProxiedObject = TypeVar("ProxiedObject")
@@ -92,7 +93,7 @@ def initialize_connection(
     `rollback_transaction()`. This is useful for allowing tests to run within their
     own transaction that is always rolled back.
     """
-    from spellbot.settings import Settings
+    from .settings import Settings
 
     settings = Settings()
     if run_migrations:  # pragma: no cover
@@ -141,11 +142,4 @@ def rollback_transaction():
         transaction.rollback()
     if not connection.closed:  # pragma: no cover
         connection.close()
-
-
-@sync_to_async
-def get_legacy_prefixes() -> dict:  # pragma: no cover
-    return {
-        row[0]: row[1]
-        for row in DatabaseSession.query(Guild.xid, Guild.legacy_prefix).all()
-    }
+    engine.dispose()
