@@ -9,10 +9,9 @@ from discord.message import Message
 from discord_slash.context import ComponentContext, InteractionContext
 from discord_slash.model import ButtonStyle
 
-from spellbot.client import SpellBot
-from spellbot.interactions import BaseInteraction
-from spellbot.models.game import GameFormat, GameStatus
-from spellbot.operations import (
+from .. import SpellBot
+from ..models import GameFormat, GameStatus
+from ..operations import (
     safe_add_role,
     safe_create_invite,
     safe_create_voice_channel,
@@ -24,7 +23,8 @@ from spellbot.operations import (
     safe_update_embed,
     safe_update_embed_origin,
 )
-from spellbot.settings import Settings
+from ..settings import Settings
+from .base_interaction import BaseInteraction
 
 logger = logging.getLogger(__name__)
 
@@ -32,14 +32,41 @@ logger = logging.getLogger(__name__)
 class LookingForGameInteraction(BaseInteraction):
     def __init__(self, bot: SpellBot, ctx: InteractionContext):
         super().__init__(bot, ctx)
+        self.settings = Settings()
 
-    async def execute(
+    async def get_friends(self, friends: Optional[str] = None) -> str:
+        return friends or ""
+
+    async def get_seats(
         self,
-        friends: Optional[str] = None,
-        seats: Optional[int] = None,
         format: Optional[int] = None,
-        message_xid: Optional[int] = None,
-    ):
+        seats: Optional[int] = None,
+    ) -> int:
+        if format and not seats:
+            return GameFormat(format).players
+        return seats or self.channel_data["default_seats"]
+
+    async def get_format(self, format: Optional[int] = None) -> int:
+        return format or GameFormat.COMMANDER.value  # type: ignore
+
+    async def filter_friend_xids(self, friend_xids: list[int]) -> list[int]:
+        assert self.ctx
+        if friend_xids:
+            friend_xids = await self.ensure_users_exist(friend_xids)
+        if friend_xids:
+            friend_xids = await self.services.games.filter_blocked(
+                self.ctx.author_id,
+                friend_xids,
+            )
+        return friend_xids
+
+    async def upsert_game(
+        self,
+        friend_xids: list[int],
+        seats: int,
+        format: int,
+        message_xid: Optional[int],
+    ) -> Optional[bool]:
         assert self.ctx
         assert self.guild
         assert self.channel
@@ -48,21 +75,75 @@ class LookingForGameInteraction(BaseInteraction):
         # False if user issued a /lfg command in chat.
         origin = bool(message_xid is not None)
 
-        friends = friends or ""
-        if format and not seats:
-            seats = GameFormat(format).players
-        else:
-            seats = seats or self.channel_data["default_seats"]
-        format = format or GameFormat.COMMANDER.value  # type: ignore
-        friend_xids = list(map(int, re.findall(r"<@!?(\d+)>", friends)))
+        if not origin:
+            return await self.services.games.upsert(
+                guild_xid=self.ctx.guild_id,
+                channel_xid=self.channel.id,
+                author_xid=self.ctx.author_id,
+                friends=friend_xids,
+                seats=seats,
+                format=format,
+            )
 
-        assert seats is not None
-        if len(friend_xids) + 1 > seats:
-            return await safe_send_channel(
+        assert message_xid
+        found = await self.services.games.select_by_message_xid(message_xid)
+        if not found or await self.services.games.blocked(self.ctx.author_id):
+            await safe_send_channel(
                 self.ctx,
-                "You mentioned too many players.",
+                "You can not join this game.",
                 hidden=True,
             )
+            return None
+
+        # Sometimes game posts have Join/Leave buttons on them even though
+        # the game has started. This can happen if an interaction fails on
+        # Discord's side of things. This makes it appear like a user can still
+        # join a game, even though it's already started. We need to handle this
+        # by informing the user and updating the game post they tried to join.
+        if found["status"] == GameStatus.STARTED.value:
+            # inform the player that their interaction failed
+            await safe_send_channel(
+                self.ctx,
+                "Sorry, that game has already started.",
+                hidden=True,
+            )
+
+            # attempt to update the problematic game post
+            message = await safe_fetch_message(
+                self.channel,
+                self.guild.id,
+                message_xid,
+            )
+            if message:
+                embed = await self.services.games.to_embed()
+                components = await self._fully_seated_components()
+                await safe_update_embed(message, embed=embed, components=components)
+
+            return None
+
+        await self.services.games.add_player(self.ctx.author_id)
+        return False
+
+    async def execute(
+        self,
+        friends: Optional[str] = None,
+        seats: Optional[int] = None,
+        format: Optional[int] = None,
+        message_xid: Optional[int] = None,
+    ):
+        if not self.ctx or not self.guild or not self.channel:  # pragma: no cover
+            # I have no idea how this is possible but I keep seeing
+            # random cases where self.channel is None here, so let's
+            # just ignore these kinds of interactions.
+            return
+
+        # True if user clicked on a Join Game button.
+        # False if user issued a /lfg command in chat.
+        origin = bool(message_xid is not None)
+
+        actual_friends: str = await self.get_friends(friends)
+        actual_seats: int = await self.get_seats(format, seats)
+        actual_format: int = await self.get_format(format)
 
         if await self.services.users.is_waiting():
             return await safe_send_channel(
@@ -71,63 +152,25 @@ class LookingForGameInteraction(BaseInteraction):
                 hidden=True,
             )
 
-        found_friends: list[int] = []
-        if friends:
-            found_friends = await self.ensure_users_exist(friend_xids)
-            found_friends = await self.services.games.filter_blocked(
-                self.ctx.author_id,
-                found_friends,
+        friend_xids = list(map(int, re.findall(r"<@!?(\d+)>", actual_friends)))
+
+        if len(friend_xids) + 1 > actual_seats:
+            return await safe_send_channel(
+                self.ctx,
+                "You mentioned too many players.",
+                hidden=True,
             )
 
-        fully_seated: bool = False
-        new: bool
-        if origin:
-            assert message_xid
-            new = False
-            found = await self.services.games.select_by_message_xid(message_xid)
-            if not found or await self.services.games.blocked(self.ctx.author_id):
-                return await safe_send_channel(
-                    self.ctx,
-                    "You can not join this game.",
-                    hidden=True,
-                )
+        friend_xids = await self.filter_friend_xids(friend_xids)
 
-            # Sometimes game posts have Join/Leave buttons on them even though
-            # the game has started. This can happen if an interaction fails on
-            # Discord's side of things. This makes it appear like a user can still
-            # join a game, even though it's already started. We need to handle this
-            # by informing the user and updating the game post they tried to join.
-            if found["status"] == GameStatus.STARTED.value:
-                # inform the player that their interaction failed
-                await safe_send_channel(
-                    self.ctx,
-                    "Sorry, that game has already started.",
-                    hidden=True,
-                )
-
-                # attempt to update the problematic game post
-                message = await safe_fetch_message(
-                    self.channel,
-                    self.guild.id,
-                    message_xid,
-                )
-                if message:
-                    embed = await self.services.games.to_embed()
-                    components = await self._fully_seated_components()
-                    await safe_update_embed(message, embed=embed, components=components)
-
-                return
-
-            await self.services.games.add_player(self.ctx.author_id)
-        else:
-            new = await self.services.games.upsert(
-                guild_xid=self.ctx.guild_id,
-                channel_xid=self.channel.id,
-                author_xid=self.ctx.author_id,
-                friends=found_friends,
-                seats=seats,
-                format=format,
-            )
+        new = await self.upsert_game(
+            friend_xids,
+            actual_seats,
+            actual_format,
+            message_xid,
+        )
+        if new is None:
+            return
 
         fully_seated = await self.services.games.fully_seated()
         if fully_seated:
@@ -178,8 +221,6 @@ class LookingForGameInteraction(BaseInteraction):
         found_players: list[int] = []
         found_players = await self.ensure_users_exist(player_xids, exclude_self=False)
 
-        # TODO: Make the players leave any games they're currently pending in?
-
         if len(found_players) != requested_seats:
             excluded_player_xids = set(player_xids) - set(found_players)
             excluded_players_s = ", ".join(f"<@{xid}>" for xid in excluded_player_xids)
@@ -216,20 +257,19 @@ class LookingForGameInteraction(BaseInteraction):
         if not await self.services.guilds.should_voice_create():
             return
 
-        settings = Settings()
         category = await safe_ensure_voice_category(
             self.bot,
             guild_xid,
-            settings.VOICE_CATEGORY_PREFIX,
+            self.settings.VOICE_CATEGORY_PREFIX,
         )
         if not category:
             return
 
-        game_id = await self.services.games.current_id()
+        game_data = await self.services.games.to_dict()
         voice_channel = await safe_create_voice_channel(
             self.bot,
             guild_xid,
-            f"Game-SB{game_id}",
+            f"Game-SB{game_data['id']}",
             category,
         )
         if not voice_channel:
@@ -240,7 +280,7 @@ class LookingForGameInteraction(BaseInteraction):
         voice_invite_link = await safe_create_invite(
             voice_channel,
             guild_xid,
-            settings.VOICE_INVITE_EXPIRE_TIME_S,
+            self.settings.VOICE_INVITE_EXPIRE_TIME_S,
         )
         await self.services.games.set_voice(voice_channel.id, voice_invite_link)
 
@@ -309,7 +349,8 @@ class LookingForGameInteraction(BaseInteraction):
             return
 
         message: Optional[discord.Message] = None
-        message_xid = await self.services.games.current_message_xid()
+        game_data = await self.services.games.to_dict()
+        message_xid = game_data["message_xid"]
         if message_xid:
             message = await safe_fetch_message(self.channel, self.guild.id, message_xid)
 
@@ -348,19 +389,18 @@ class LookingForGameInteraction(BaseInteraction):
 
     async def _reply_found_embed(self):
         assert self.ctx
-        settings = Settings()
         embed = Embed()
-        embed.set_thumbnail(url=settings.ICO_URL)
+        embed.set_thumbnail(url=self.settings.ICO_URL)
         embed.set_author(name="I found a game for you!")
-        link = await self.services.games.jump_link()
+        game_data = await self.services.games.to_dict()
+        link = game_data["jump_link"]
         embed.description = f"You can [jump to the game post]({link}) to see it!"
-        embed.color = settings.EMBED_COLOR
+        embed.color = self.settings.EMBED_COLOR
         await safe_send_channel(self.ctx, embed=embed, hidden=True)
 
     async def _handle_direct_messages(self):
         assert self.ctx
-        settings = Settings()
-        player_xids = await self.services.games.current_player_xids()
+        player_xids = await self.services.games.player_xids()
         embed = await self.services.games.to_embed(dm=True)
         failed_xids: list[int] = []
 
@@ -392,11 +432,15 @@ class LookingForGameInteraction(BaseInteraction):
             warning = f"Unable to send Direct Messages to some players: {failures}"
             await safe_send_channel(self.ctx, warning)
 
-        # notify moderators about watched players
+        await self._handle_watched_players(player_xids)
+
+    async def _handle_watched_players(self, player_xids: list[int]):
+        """Notify moderators about watched players."""
+        assert self.ctx
         assert self.ctx.guild
         mod_role: Optional[discord.Role] = None
         for role in self.ctx.guild.roles:
-            if role.name.startswith(settings.MOD_PREFIX):
+            if role.name.startswith(self.settings.MOD_PREFIX):
                 mod_role = role
                 break
 
@@ -410,9 +454,9 @@ class LookingForGameInteraction(BaseInteraction):
         data = await self.services.games.to_dict()
 
         embed = Embed()
-        embed.set_thumbnail(url=settings.ICO_URL)
+        embed.set_thumbnail(url=self.settings.ICO_URL)
         embed.set_author(name="Watched user(s) joined a game")
-        embed.color = settings.EMBED_COLOR
+        embed.color = self.settings.EMBED_COLOR
         description = (
             f"[⇤ Jump to the game post]({data['jump_link']})\n"
             f"[➤ Spectate the game on SpellTable]({data['spectate_link']})\n\n"
