@@ -2,13 +2,15 @@ from typing import TYPE_CHECKING
 
 from sqlalchemy import BigInteger, Column, ForeignKey
 
-from . import Base
+from .base import Base
 
 if TYPE_CHECKING:  # pragma: no cover
     from .user import User  # noqa
 
 
 class Block(Base):
+    """Allows users to block other users."""
+
     __tablename__ = "blocks"
 
     user_xid = Column(
