@@ -2,7 +2,7 @@ from typing import TYPE_CHECKING
 
 from sqlalchemy import BigInteger, Column, ForeignKey, Integer
 
-from . import Base
+from .base import Base
 
 if TYPE_CHECKING:  # pragma: no cover
     from .game import Game  # noqa
@@ -10,6 +10,8 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class Play(Base):
+    """Records of a users game plays."""
+
     __tablename__ = "plays"
 
     user_xid = Column(
