@@ -1,3 +1,5 @@
+# pylint: disable=wrong-import-order
+
 from datetime import datetime
 from typing import Optional
 
@@ -6,16 +8,16 @@ from asgiref.sync import sync_to_async
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import update
 
-from spellbot.database import DatabaseSession
-from spellbot.models.channel import Channel
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Channel
 
 
-class ChannelsService(BaseService):
+class ChannelsService:
     @sync_to_async()
     def upsert(self, channel: discord.TextChannel) -> dict:
         name_max_len = Channel.name.property.columns[0].type.length  # type: ignore
-        name = channel.name[:name_max_len]
+        raw_name = getattr(channel, "name", "")
+        name = raw_name[:name_max_len]
         values = {
             "xid": channel.id,
             "guild_xid": channel.guild.id,
@@ -65,3 +67,15 @@ class ChannelsService(BaseService):
         query = update(Channel).where(Channel.xid == xid).values(unverified_only=setting)
         DatabaseSession.execute(query)
         DatabaseSession.commit()
+
+    @sync_to_async()
+    def set_motd(self, xid: int, message: Optional[str] = None) -> str:
+        if message:
+            max_len = Channel.motd.property.columns[0].type.length  # type: ignore
+            motd = message[:max_len]
+        else:
+            motd = ""
+        query = update(Channel).where(Channel.xid == xid).values(motd=motd)
+        DatabaseSession.execute(query)
+        DatabaseSession.commit()
+        return motd
