@@ -1,3 +1,5 @@
+# pylint: disable=wrong-import-order
+
 from datetime import datetime, timedelta
 from typing import Optional
 
@@ -8,15 +10,9 @@ from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_, asc, column, or_, select
 from sqlalchemy.sql.functions import count
 
-from spellbot.database import DatabaseSession
-from spellbot.models.award import UserAward
-from spellbot.models.block import Block
-from spellbot.models.game import Game, GameStatus
-from spellbot.models.play import Play
-from spellbot.models.user import User
-from spellbot.models.watch import Watch
-from spellbot.services import BaseService
-from spellbot.settings import Settings
+from ..database import DatabaseSession
+from ..models import Block, Game, GameStatus, Play, User, UserAward, Watch
+from ..settings import Settings
 
 MAX_SPELLTABLE_LINK_LEN = Game.spelltable_link.property.columns[  # type: ignore
     0
@@ -26,7 +22,7 @@ MAX_VOICE_INVITE_LINK_LEN = Game.voice_invite_link.property.columns[  # type: ig
 ].type.length
 
 
-class GamesService(BaseService):
+class GamesService:
     def __init__(self):
         self.game: Optional[Game] = None
 
@@ -57,12 +53,6 @@ class GamesService(BaseService):
         )
         return self.game.to_dict() if self.game else None
 
-    @sync_to_async
-    def current_status(self) -> bool:
-        assert self.game
-        rows = DatabaseSession.query(User).filter(User.game_id == self.game.id).count()
-        return rows + 1 <= self.game.seats
-
     @sync_to_async
     def add_player(self, player_xid: int) -> None:
         assert self.game
@@ -125,7 +115,7 @@ class GamesService(BaseService):
         DatabaseSession.execute(
             update(User)
             .where(User.xid.in_([*friends, author_xid]))
-            .values(game_id=game.id)
+            .values(game_id=game.id),
         )
         DatabaseSession.commit()
         self.game = game
@@ -148,7 +138,7 @@ class GamesService(BaseService):
                     Game,
                     User.xid.label("users_xid"),
                     count(User.xid).over(partition_by=Game.id).label("player_count"),
-                ]
+                ],
             )
             .join(User, isouter=True)
             .filter(  # type: ignore
@@ -158,17 +148,17 @@ class GamesService(BaseService):
                     Game.seats == seats,
                     Game.format == format,
                     Game.status == GameStatus.PENDING.value,
-                )
+                ),
             )
             .group_by(Game, User.xid)
             .order_by(asc(Game.updated_at))
             .alias("inner")
         )
         user_blocks = DatabaseSession.query(Block.blocked_user_xid).filter_by(
-            user_xid=author_xid
+            user_xid=author_xid,
         )
         blocks_user = DatabaseSession.query(Block.user_xid).filter_by(
-            blocked_user_xid=author_xid
+            blocked_user_xid=author_xid,
         )
         outer = (
             DatabaseSession.query(Game)
@@ -184,7 +174,7 @@ class GamesService(BaseService):
                         ~inner.c.users_xid.in_(user_blocks),
                         ~inner.c.users_xid.in_(blocks_user),
                     ),
-                )
+                ),
             )
         )
         return outer.first()
@@ -200,23 +190,6 @@ class GamesService(BaseService):
         self.game.message_xid = message_xid  # type: ignore
         DatabaseSession.commit()
 
-    @sync_to_async
-    def current_guild_xid(self) -> int:
-        assert self.game
-        assert self.game.guild_xid
-        return self.game.guild_xid
-
-    @sync_to_async
-    def current_channel_xid(self) -> int:
-        assert self.game
-        assert self.game.channel_xid
-        return self.game.channel_xid
-
-    @sync_to_async
-    def current_message_xid(self) -> Optional[int]:
-        assert self.game
-        return self.game.message_xid
-
     @sync_to_async
     def fully_seated(self) -> bool:
         assert self.game
@@ -233,7 +206,7 @@ class GamesService(BaseService):
         DatabaseSession.commit()
 
     @sync_to_async
-    def current_player_xids(self) -> list[int]:
+    def player_xids(self) -> list[int]:
         assert self.game
         rows = DatabaseSession.query(User.xid).filter(User.game_id == self.game.id)
         return [int(row[0]) for row in rows]
@@ -247,7 +220,7 @@ class GamesService(BaseService):
                 and_(
                     Watch.guild_xid == self.game.guild_xid,
                     Watch.user_xid.in_(player_xids),
-                )
+                ),
             )
             .all()
         )
@@ -268,9 +241,12 @@ class GamesService(BaseService):
         DatabaseSession.execute(
             insert(Play)
             .values(
-                [dict(user_xid=player_xid, game_id=game_id) for player_xid in player_xids]
+                [
+                    dict(user_xid=player_xid, game_id=game_id)
+                    for player_xid in player_xids
+                ],
             )
-            .on_conflict_do_nothing()
+            .on_conflict_do_nothing(),
         )
 
         # upsert into user_awards
@@ -280,18 +256,13 @@ class GamesService(BaseService):
                 [
                     dict(guild_xid=guild_xid, user_xid=player_xid)
                     for player_xid in player_xids
-                ]
+                ],
             )
-            .on_conflict_do_nothing()
+            .on_conflict_do_nothing(),
         )
 
         DatabaseSession.commit()
 
-    @sync_to_async
-    def current_id(self) -> int:
-        assert self.game
-        return self.game.id
-
     @sync_to_async
     def set_voice(self, voice_xid: int, voice_invite_link: str) -> None:
         assert self.game
@@ -314,14 +285,14 @@ class GamesService(BaseService):
                         Block.blocked_user_xid == author_xid,
                         Block.user_xid.in_(other_xids),
                     ),
-                )
+                ),
             )
             .all()
         )
         return list(
             set(other_xids)
             - set(blocker.user_xid for blocker in blockers)
-            - set(blocker.blocked_user_xid for blocker in blockers)
+            - set(blocker.blocked_user_xid for blocker in blockers),
         )
 
     @sync_to_async
@@ -340,20 +311,10 @@ class GamesService(BaseService):
                     Block.blocked_user_xid == author_xid,
                     Block.user_xid.in_(other_player_xids),
                 ),
-            )
+            ),
         )
         return bool(DatabaseSession.query(query.exists()).scalar())
 
-    @sync_to_async
-    def jump_link(self) -> str:
-        assert self.game
-        return self.game.jump_link
-
-    @sync_to_async
-    def to_dict(self) -> dict:
-        assert self.game
-        return self.game.to_dict()
-
     @sync_to_async
     def players_included(self, player_xid: int) -> bool:
         """
@@ -368,7 +329,7 @@ class GamesService(BaseService):
                 and_(
                     Play.user_xid == player_xid,
                     Play.game_id == self.game.id,
-                )
+                ),
             )
             .one_or_none()
         )
@@ -394,6 +355,11 @@ class GamesService(BaseService):
         DatabaseSession.execute(upsert, values)
         DatabaseSession.commit()
 
+    @sync_to_async
+    def to_dict(self) -> dict:
+        assert self.game
+        return self.game.to_dict()
+
     @sync_to_async
     def inactive_games(self) -> list[dict]:
         settings = Settings()
@@ -402,7 +368,7 @@ class GamesService(BaseService):
             and_(
                 Game.status == GameStatus.PENDING.value,
                 Game.updated_at <= limit,
-            )
+            ),
         )
         return [record.to_dict() for record in records]
 
