@@ -1,12 +1,12 @@
+# pylint: disable=wrong-import-order
+
 from asgiref.sync import sync_to_async
 from dateutil import tz
 from sqlalchemy.sql.elements import TextClause
 from sqlalchemy.sql.expression import and_, text
 
-from spellbot.database import DatabaseSession
-from spellbot.models.game import Game, GameFormat
-from spellbot.models.play import Play
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Game, GameFormat, Play
 
 CHANNEL_FILTER = "games.channel_xid = :channel_xid"
 USER_FILTER = "plays.user_xid = :user_xid"
@@ -42,13 +42,14 @@ RECORDS_SQL = """
         channels.name,
         STRING_AGG(
             CONCAT(
-                users.name,
+                REPLACE(REPLACE(users.name, ':', ''), '@', ''),
                 ':',
                 users.xid,
                 ':',
                 COALESCE(plays.points, 0)::text
             ),
             '@'
+            ORDER BY users.xid
         )
     FROM
         game_plays
@@ -73,7 +74,7 @@ RECORDS_SQL = """
 """
 
 
-class PlaysService(BaseService):
+class PlaysService:
     @sync_to_async()
     def count(self, user_xid: int, guild_xid: int) -> int:
         return int(
@@ -83,10 +84,10 @@ class PlaysService(BaseService):
                 and_(
                     Play.user_xid == user_xid,
                     Game.guild_xid == guild_xid,
-                )
+                ),
             )
             .count()
-            or 0
+            or 0,
         )
 
     def _records(
