@@ -1,3 +1,5 @@
+# pylint: disable=wrong-import-order
+
 from datetime import datetime
 from typing import Any, Optional, Union
 
@@ -7,15 +9,11 @@ from sqlalchemy import update
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_
 
-from spellbot.database import DatabaseSession
-from spellbot.models.block import Block
-from spellbot.models.game import Game
-from spellbot.models.user import User
-from spellbot.models.watch import Watch
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Block, Game, User, Watch
 
 
-class UsersService(BaseService):
+class UsersService:
     def __init__(self):
         self.user: Optional[User] = None
 
@@ -23,13 +21,10 @@ class UsersService(BaseService):
     def upsert(self, target: Union[discord.User, discord.Member]) -> dict:
         assert hasattr(target, "id")
         xid = target.id  # type: ignore
-        name = target.display_name
         max_name_len = User.name.property.columns[0].type.length  # type: ignore
-        values = {
-            "xid": xid,
-            "name": name[:max_name_len],
-            "updated_at": datetime.utcnow(),
-        }
+        raw_name = getattr(target, "display_name", "")
+        name = raw_name[:max_name_len]
+        values = {"xid": xid, "name": name, "updated_at": datetime.utcnow()}
         upsert = insert(User).values(**values)
         upsert = upsert.on_conflict_do_update(
             index_elements=[User.xid],
@@ -128,7 +123,7 @@ class UsersService(BaseService):
             and_(
                 Block.user_xid == author_xid,
                 Block.blocked_user_xid == target_xid,
-            )
+            ),
         ).delete(synchronize_session=False)
         DatabaseSession.commit()
 
@@ -161,6 +156,6 @@ class UsersService(BaseService):
             and_(
                 Watch.guild_xid == guild_xid,
                 Watch.user_xid == user_xid,
-            )
+            ),
         ).delete(synchronize_session=False)
         DatabaseSession.commit()
